@@ -3,7 +3,7 @@ from graphmanagerlib.Node import Node
 from graphmanagerlib.Document import Document
 
 def GetJsonFromFile(jsonPath):
-    f = open(jsonPath, )
+    f = open(jsonPath, encoding="utf8")
     result = json.load(f)
     f.close()
     return result
